<!-- Feel free to remove check-list items aren't relevant to your changes -->

- [ ] Closes #xxxx
- [ ] Tests added and `pixi r -e test310 test` and `pixi r -e test313 test` pass.
- [ ] Changes and the contributor name are documented in `CHANGELOG.md`.
